pub fn light_face_occludes(
from_state: BlockStateId,
to_state: BlockStateId,
direction: Direction,
) -> boolExpand description
Returns whether the selected state faces fully occlude light.
pub fn light_face_occludes(
from_state: BlockStateId,
to_state: BlockStateId,
direction: Direction,
) -> boolReturns whether the selected state faces fully occlude light.