pub fn light_occlusion_shape(state: BlockStateId) -> VoxelShapeExpand description
Returns the occlusion shape vanilla lighting uses for a block state.
pub fn light_occlusion_shape(state: BlockStateId) -> VoxelShapeReturns the occlusion shape vanilla lighting uses for a block state.