pub fn propagate_sky_light_chunk_without_edge_checks(
workset: &LightWorkset,
) -> Result<SkyLightUpdateResult, SkyLightPropagationContextError>Expand description
Seeds and propagates sky light for the center chunk without edge checks.
pub fn propagate_sky_light_chunk_without_edge_checks(
workset: &LightWorkset,
) -> Result<SkyLightUpdateResult, SkyLightPropagationContextError>Seeds and propagates sky light for the center chunk without edge checks.