pub struct LightSectionRange {
min_section_y: i32,
section_count: i32,
}Expand description
Inclusive/exclusive vertical range of light sections for a level.
Vanilla’s LevelLightEngine exposes this as getMinLightSection(),
getMaxLightSection(), and getLightSectionCount(). The range is padded by
one section below and one section above the real chunk sections.
Fields
min_section_y: i32section_count: i32Implementations
Sourceimpl LightSectionRange
impl LightSectionRange
Sourcepub const fn from_world_height(
min_y: i32,
height: i32,
) -> Result<Self, LightSectionRangeError>
pub const fn from_world_height( min_y: i32, height: i32, ) -> Result<Self, LightSectionRangeError>
Creates the vanilla padded light-section range for a world height.
Sourcepub const fn min_section_y(self) -> i32
pub const fn min_section_y(self) -> i32
Returns the first light section Y coordinate.
Sourcepub const fn max_section_y_exclusive(self) -> i32
pub const fn max_section_y_exclusive(self) -> i32
Returns the section Y coordinate one past the last light section.
Sourcepub const fn section_count(self) -> usize
pub const fn section_count(self) -> usize
Returns the number of light sections in this range.
Sourcepub const fn min_chunk_section_y(self) -> i32
pub const fn min_chunk_section_y(self) -> i32
Returns the first real chunk section Y coordinate.
Sourcepub const fn max_chunk_section_y_exclusive(self) -> i32
pub const fn max_chunk_section_y_exclusive(self) -> i32
Returns the real chunk section Y coordinate one past the last section.
Sourcepub const fn chunk_section_count(self) -> usize
pub const fn chunk_section_count(self) -> usize
Returns the number of real chunk sections inside this light range.
Sourcepub const fn section_y(self, section_index: usize) -> Option<i32>
pub const fn section_y(self, section_index: usize) -> Option<i32>
Converts a packet light-section index to a section Y coordinate.
Sourcepub const fn section_index(self, section_y: i32) -> Option<usize>
pub const fn section_index(self, section_y: i32) -> Option<usize>
Converts a section Y coordinate to a packet light-section index.
Sourcepub const fn chunk_section_y(self, section_index: usize) -> Option<i32>
pub const fn chunk_section_y(self, section_index: usize) -> Option<i32>
Converts a real chunk-section index to a section Y coordinate.
Sourcepub const fn chunk_section_index(self, section_y: i32) -> Option<usize>
pub const fn chunk_section_index(self, section_y: i32) -> Option<usize>
Converts a real chunk section Y coordinate to an emptiness-map index.
pub(super) fn empty_bit_set(self) -> BitSet