pub struct PackedLightPropagationQueue {
entries: Vec<PackedLightQueueEntry>,
read_index: usize,
}Expand description
Array-backed FIFO used for ScalableLux packed light propagation entries.
Fields
entries: Vec<PackedLightQueueEntry>read_index: usizeImplementations
Sourceimpl PackedLightPropagationQueue
impl PackedLightPropagationQueue
Sourcepub const fn len(&self) -> usize
pub const fn len(&self) -> usize
Returns the number of packed entries that have not been dequeued yet.
Sourcepub fn enqueue(&mut self, entry: PackedLightQueueEntry)
pub fn enqueue(&mut self, entry: PackedLightQueueEntry)
Adds packed propagation work to the back of the queue.
Sourcepub fn dequeue(&mut self) -> Option<PackedLightQueueEntry>
pub fn dequeue(&mut self) -> Option<PackedLightQueueEntry>
Removes packed propagation work from the front of the queue.